@@ -20,22 +20,25 @@ class WriteRequests(object):
 
     """
 
-    def process_request(self, request):
+    def process_response(self, request, response):
         """
-        обработчик запроса
+        записываем параметры запроса и ответа
         """
-        if (request.session.get('debug_on', False)
-            and 'debug_file_path' in request.session
-            and os.path.exists(request.session['debug_file_path'])
+        if (request.COOKIES.get('debug_on', False)
+            and 'debug_file_path' in request.COOKIES
+            and os.path.exists(request.COOKIES['debug_file_path'])
             and 'smoknur' not in request.META['PATH_INFO']
             and 'media' not in request.META['PATH_INFO']):
-            # включена отладочная запись 
+            # включена отладочная запись
             # имеется путь к файлу
             # файл существует
             # записываем отладочную информацию
 
             text = json.dumps({
                 'url': request.META['PATH_INFO'],
-                'params': request.POST
+                'params': request.POST,
+                'status_code': response.status_code,
+                'method': request.method
             })
-            open(request.session['debug_file_path'], 'a').write(text + '\n')
+            open(request.COOKIES['debug_file_path'], 'a').write(text + '\n')
+        return response
